# API Reference:

<div class="grid cards" markdown>

- [Inference](inference.md)
  <br/>
  *SBI algorithms and helper functions.*
- [Neural Networks](models.md)
  <br/>
  *Utilities to build neural network-based density estimators and feature extractors.*
- [Posteriors](posteriors.md)
  <br/>
  *Posterior classes*
- [Potentials](potentials.md)
  <br/>
  *Potential function classes for posterior sampling.*
- [Analysis](analysis.md)
  <br/>
  *Utilities for SBI visualizations and analyses.*

</div>
